src/eric7/Templates/TemplatePropertiesDialog.py

branch
eric7
changeset 10431
64157aeb0312
parent 10373
093dcebe5ecb
child 10439
21c28b0f9e41
--- a/src/eric7/Templates/TemplatePropertiesDialog.py	Wed Dec 20 19:28:22 2023 +0100
+++ b/src/eric7/Templates/TemplatePropertiesDialog.py	Thu Dec 21 12:03:40 2023 +0100
@@ -28,10 +28,12 @@
         """
         Constructor
 
-        @param parent the parent widget (QWidget)
-        @param groupMode flag indicating group mode (boolean)
-        @param itm item (TemplateEntry or TemplateGroup) to
-            read the data from
+        @param parent the parent widget
+        @type QWidget
+        @param groupMode flag indicating group mode
+        @type bool
+        @param itm item to read the data from
+        @type TemplateEntry or TemplateGroup
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -96,7 +98,8 @@
         """
         Protected method to handle the user pressing the escape key.
 
-        @param ev key event (QKeyEvent)
+        @param ev key event
+        @type QKeyEvent
         """
         if ev.key() == Qt.Key.Key_Escape:
             res = EricMessageBox.yesNo(
@@ -211,7 +214,8 @@
         """
         Public method to select a group.
 
-        @param name name of the group to be selected (string)
+        @param name name of the group to be selected
+        @type str
         """
         index = self.groupCombo.findText(name)
         self.groupCombo.setCurrentIndex(index)
@@ -220,9 +224,10 @@
         """
         Public method to get the data entered into the dialog.
 
-        @return a tuple of two strings (name, language), if the dialog is in
-            group mode, and a tuple of four strings (name, description, group
-            name, template) otherwise.
+        @return a tuple containing the name and language, if the dialog is in
+            group mode, or a tuple containing the name, description, group name
+            and template otherwise.
+        @rtype tuple of (str, str) or tuple of (str, str, str, str)
         """
         if self.groupMode:
             return (

eric ide

mercurial